##  YesSQL

[![build-test-docs-publish](https://github.com/mitchelllisle/yessql/actions/workflows/run-build-tests-docs-publish.yaml/badge.svg?branch=main)](https://github.com/mitchelllisle/yessql/actions/workflows/run-build-tests-docs-publish.yaml)
[![CodeQL](https://github.com/mitchelllisle/yessql/actions/workflows/codeql-analysis.yml/badge.svg?branch=main)](https://github.com/mitchelllisle/yessql/actions/workflows/codeql-analysis.yml)

Coming soon...
